Enum some_auth::AuthError

source ·
pub enum AuthError {
    Internal(String),
    ValidationError(String),
    UsernameUnavailable,
    InvalidCredentials,
    AuthRepositoryError(String),
    UserNotFound(String),
    InvalidOperation(String),
    Unathorized,
}
Errors connected to auth mechanisms

Variants



Internal(String)

Auth problem connected with some internal error



ValidationError(String)

Validation error in auth’ domain



UsernameUnavailable

Provided username is unavailable



InvalidCredentials

Invalid credentials. This module returns such error in most cases when there are some problems with user validation to provide less information for potential intruder



AuthRepositoryError(String)

Error connected with UserRepository



UserNotFound(String)

User with not found. Inner string represents info about user



InvalidOperation(String)

Current operation is invalid



Unathorized

User is unathorized